@@ -17,7 +17,6 @@ from typing import Union
 
 from ddtrace import config
 from ddtrace.filters import TraceFilter
-from ddtrace.internal.utils.deprecations import DDTraceDeprecationWarning
 from ddtrace.vendor import debtcollector
 
 from . import _hooks
@@ -36,7 +35,6 @@ from .internal import compat
 from .internal import debug
 from .internal import forksafe
 from .internal import hostname
-from .internal import service
 from .internal.dogstatsd import get_dogstatsd_client
 from .internal.logger import get_logger
 from .internal.logger import hasHandlers
@@ -47,8 +45,8 @@ from .internal.processor.trace import TraceSamplingProcessor
 from .internal.processor.trace import TraceTagsProcessor
 from .internal.processor.trace import TraceTopLevelSpanProcessor
 from .internal.runtime import get_runtime_id
+from .internal.service import ServiceStatusError
 from .internal.utils.formats import asbool
-from .internal.utils.formats import get_env
 from .internal.writer import AgentWriter
 from .internal.writer import LogWriter
 from .internal.writer import TraceWriter
@@ -59,19 +57,23 @@ from .sampler import DatadogSampler
 from .sampler import RateByServiceSampler
 from .sampler import RateSampler
 from .span import Span
-from .vendor.debtcollector import removals
 
 
 log = get_logger(__name__)
 
-debug_mode = asbool(get_env("trace", "debug", default=False))
-call_basic_config = asbool(os.environ.get("DD_CALL_BASIC_CONFIG", "true"))
+debug_mode = asbool(os.getenv("DD_TRACE_DEBUG", default=False))
+call_basic_config = asbool(os.environ.get("DD_CALL_BASIC_CONFIG", "false"))
 
 DD_LOG_FORMAT = "%(asctime)s %(levelname)s [%(name)s] [%(filename)s:%(lineno)d] {}- %(message)s".format(
     "[dd.service=%(dd.service)s dd.env=%(dd.env)s dd.version=%(dd.version)s"
     " dd.trace_id=%(dd.trace_id)s dd.span_id=%(dd.span_id)s] "
 )
 if debug_mode and not hasHandlers(log) and call_basic_config:
+    debtcollector.deprecate(
+        "ddtrace.tracer.logging.basicConfig",
+        message="`logging.basicConfig()` should be called in a user's application."
+        " ``DD_CALL_BASIC_CONFIG`` will be removed in a future version.",
+    )
     if config.logs_injection:
         # We need to ensure logging is patched in case the tracer logs during initialization
         patch(logging=True)
@@ -125,7 +127,7 @@ class Tracer(object):
         # traces
         self._pid = getpid()
 
-        self.enabled = asbool(get_env("trace", "enabled", default=True))
+        self.enabled = asbool(os.getenv("DD_TRACE_ENABLED", default=True))
         self.context_provider = DefaultContextProvider()
         self._sampler = DatadogSampler()  # type: BaseSampler
         self._priority_sampler = RateByServiceSampler()  # type: Optional[BasePrioritySampler]
@@ -147,24 +149,8 @@ class Tracer(object):
             )
         self._writer = writer  # type: TraceWriter
 
-        # DD_TRACER_... should be deprecated after version 1.0.0 is released
-        pfe_default_value = False
-        pfms_default_value = 500
-        if "DD_TRACER_PARTIAL_FLUSH_ENABLED" in os.environ or "DD_TRACER_PARTIAL_FLUSH_MIN_SPANS" in os.environ:
-            debtcollector.deprecate(
-                "DD_TRACER_... is deprecated",
-                message="use DD_TRACE_... instead",
-                category=DDTraceDeprecationWarning,
-                removal_version="1.0.0",
-            )
-            pfe_default_value = asbool(get_env("tracer", "partial_flush_enabled", default=pfe_default_value))
-            pfms_default_value = int(
-                get_env("tracer", "partial_flush_min_spans", default=pfms_default_value)  # type: ignore[arg-type]
-            )
-        self._partial_flush_enabled = asbool(get_env("trace", "partial_flush_enabled", default=pfe_default_value))
-        self._partial_flush_min_spans = int(
-            get_env("trace", "partial_flush_min_spans", default=pfms_default_value)  # type: ignore[arg-type]
-        )
+        self._partial_flush_enabled = asbool(os.getenv("DD_TRACE_PARTIAL_FLUSH_ENABLED", default=False))
+        self._partial_flush_min_spans = int(os.getenv("DD_TRACE_PARTIAL_FLUSH_MIN_SPANS", default=500))
 
         self._initialize_span_processors()
         self._hooks = _hooks.Hooks()
@@ -209,66 +195,10 @@ class Tracer(object):
         self._hooks.deregister(self.__class__.start_span, func)
         return func
 
-    @removals.removed_property(
-        message="Use ddtrace.tracer.log instead", category=DDTraceDeprecationWarning, removal_version="1.0.0"
-    )
-    def log(self):
-        # type: () -> logging.Logger
-        return log
-
-    @log.setter  # type: ignore
-    def log(self, value):
-        # type: (logging.Logger) -> None
-        global log
-        log = value
-
     @property
     def debug_logging(self):
         return log.isEnabledFor(logging.DEBUG)
 
-    @debug_logging.setter  # type: ignore[misc]
-    @removals.remove(
-        message="Use logging.setLevel instead", category=DDTraceDeprecationWarning, removal_version="1.0.0"
-    )
-    def debug_logging(self, value):
-        # type: (bool) -> None
-        log.setLevel(logging.DEBUG if value else logging.WARN)
-
-    @removals.remove(category=DDTraceDeprecationWarning, removal_version="1.0.0")
-    def __call__(self):
-        return self
-
-    @removals.remove(category=DDTraceDeprecationWarning, removal_version="1.0.0")
-    def global_excepthook(self, tp, value, traceback):
-        """The global tracer except hook."""
-
-    @removals.remove(
-        message="Call context has been superseded by trace context. Please use current_trace_context() instead.",
-        category=DDTraceDeprecationWarning,
-        removal_version="1.0.0",
-    )
-    def get_call_context(self, *args, **kwargs):
-        # type: (...) -> Context
-        """
-        Return the current active ``Context`` for this traced execution. This method is
-        automatically called in the ``tracer.trace()``, but it can be used in the application
-        code during manual instrumentation like::
-
-            from ddtrace import tracer
-
-            async def web_handler(request):
-                context = tracer.get_call_context()
-                # use the context if needed
-                # ...
-
-        This method makes use of a ``ContextProvider`` that is automatically set during the tracer
-        initialization, or while using a library instrumentation.
-        """
-        ctx = self.current_trace_context(*args, **kwargs)
-        if ctx is None:
-            ctx = Context()
-        return ctx
-
     def current_trace_context(self, *args, **kwargs):
         # type: (...) -> Optional[Context]
         """Return the context for the current trace.
@@ -289,18 +219,18 @@ class Tracer(object):
         span id of the current active span, as well as the configured service, version, and environment names.
         If there is no active span, a dictionary with an empty string for each value will be returned.
         """
-        span = None
+        active = None  # type: Optional[Union[Context, Span]]
         if self.enabled:
-            span = self.current_span()
+            active = self.context_provider.active()
 
-        if span and span.service:
-            service = span.service
+        if isinstance(active, Span) and active.service:
+            service = active.service
         else:
             service = config.service
 
         return {
-            "trace_id": str(span.trace_id) if span else "0",
-            "span_id": str(span.span_id) if span else "0",
+            "trace_id": str(active.trace_id) if active else "0",
+            "span_id": str(active.span_id) if active else "0",
             "service": service or "",
             "version": config.version or "",
             "env": config.env or "",
@@ -402,8 +332,8 @@ class Tracer(object):
 
         try:
             self._writer.stop()
-        except service.ServiceStatusError:
-            # It's possible the writer never got started in the first place :(
+        except ServiceStatusError:
+            # It's possible the writer never got started
             pass
 
         if writer is not None:
@@ -464,6 +394,19 @@ class Tracer(object):
 
         self._new_process = True
 
+    def _start_span_after_shutdown(
+        self,
+        name,  # type: str
+        child_of=None,  # type: Optional[Union[Span, Context]]
+        service=None,  # type: Optional[str]
+        resource=None,  # type: Optional[str]
+        span_type=None,  # type: Optional[str]
+        activate=False,  # type: bool
+    ):
+        # type: (...) -> Span
+        log.warning("Spans started after the tracer has been shut down will not be sent to the Datadog Agent.")
+        return self._start_span(name, child_of, service, resource, span_type, activate)
+
     def _start_span(
         self,
         name,  # type: str
@@ -564,7 +507,6 @@ class Tracer(object):
         if trace_id:
             # child_of a non-empty context, so either a local child span or from a remote context
             span = Span(
-                tracer=None,
                 name=name,
                 context=context,
                 trace_id=trace_id,
@@ -586,7 +528,6 @@ class Tracer(object):
         else:
             # this is the root span of a new trace
             span = Span(
-                tracer=None,
                 name=name,
                 context=context,
                 service=mapped_service,
@@ -658,9 +599,6 @@ class Tracer(object):
             for p in self._span_processors:
                 p.on_span_start(span)
 
-        # Set Span.tracer for backwards compatibility, will be removed in v1.0
-        span._tracer = self
-
         self._hooks.emit(self.__class__.start_span, span)
         return span
 
@@ -682,7 +620,7 @@ class Tracer(object):
         if log.isEnabledFor(logging.DEBUG):
             log.debug("finishing span %s (enabled:%s)", span._pprint(), self.enabled)
 
-    def _initialize_span_processors(self, appsec_enabled=asbool(get_env("appsec", "enabled", default=False))):
+    def _initialize_span_processors(self, appsec_enabled=asbool(os.getenv("DD_APPSEC_ENABLED", default=False))):
         # type: (Optional[bool]) -> None
         trace_processors = []  # type: List[TraceProcessor]
         trace_processors += [TraceTagsProcessor()]
@@ -735,7 +673,7 @@ class Tracer(object):
         else:
             log.log(level, msg)
 
-    def _trace(self, name, service=None, resource=None, span_type=None):
+    def trace(self, name, service=None, resource=None, span_type=None):
         # type: (str, Optional[str], Optional[str], Optional[str]) -> Span
         """Activate and return a new span that inherits from the current active span.
 
@@ -786,8 +724,6 @@ class Tracer(object):
             activate=True,
         )
 
-    trace = _trace
-
     def current_root_span(self):
         # type: () -> Optional[Span]
         """Returns the root span of the current execution.
@@ -819,65 +755,6 @@ class Tracer(object):
         active = self.context_provider.active()
         return active if isinstance(active, Span) else None
 
-    @debtcollector.removals.remove(
-        message="Writing spans through a tracer is no longer supported",
-        category=DDTraceDeprecationWarning,
-        removal_version="1.0.0",
-    )
-    def write(self, spans):
-        # type: (Optional[List[Span]]) -> None
-        """
-        Send the trace to the writer to enqueue the spans list in the agent
-        sending queue.
-        """
-        if not spans:
-            return  # nothing to do
-
-        if log.isEnabledFor(logging.DEBUG):
-            log.debug("writing %s spans (enabled:%s)", len(spans), self.enabled)
-            for span in spans:
-                log.debug("\n%s", span._pprint())
-
-        if not self.enabled:
-            return
-
-        if spans is not None:
-            self._writer.write(spans=spans)
-
-    @removals.removed_property(category=DDTraceDeprecationWarning, removal_version="1.0.0")
-    def priority_sampler(self):
-        # type: () -> Optional[BasePrioritySampler]
-        return self._priority_sampler
-
-    @priority_sampler.setter  # type: ignore[no-redef]
-    def priority_sampler(self, val):
-        # type: (Optional[BasePrioritySampler]) -> None
-        self._priority_sampler = val
-
-    @removals.removed_property(removal_version="1.0.0")
-    def sampler(self):
-        # type: () -> BaseSampler
-        return self._sampler
-
-    @sampler.setter  # type: ignore[no-redef]
-    def sampler(self, val):
-        # type: (BaseSampler) -> None
-        self._sampler = val
-
-    @removals.removed_property(category=DDTraceDeprecationWarning, removal_version="1.0.0")
-    def tags(self):
-        # type: () -> dict[str, str]
-        return self._tags
-
-    @tags.setter  # type: ignore
-    def tags(self, t):
-        # type: (dict[str, str]) -> None
-        self._tags = t
-
-    @removals.removed_property(message="Use Tracer.flush instead to flush buffered traces to agent", version="1.0.0")
-    def writer(self):
-        return self._writer
-
     @property
     def agent_trace_url(self):
         # type: () -> Optional[str]
@@ -891,15 +768,6 @@ class Tracer(object):
         """Flush the buffer of the trace writer. This does nothing if an unbuffered trace writer is used."""
         self._writer.flush_queue()
 
-    @removals.remove(
-        message="Manually setting service info is no longer necessary",
-        category=DDTraceDeprecationWarning,
-        removal_version="1.0.0",
-    )
-    def set_service_info(self, *args, **kwargs):
-        """Set the information about the given service."""
-        return
-
     def wrap(
         self,
         name=None,  # type: Optional[str]
@@ -1006,68 +874,26 @@ class Tracer(object):
         """
         self._tags.update(tags)
 
-    def _restore_from_shutdown(self):
-        with self._shutdown_lock:
-            if self.start_span is self._start_span:
-                # Already restored
-                return
-
-            atexit.register(self._atexit)
-            forksafe.register(self._child_after_fork)
-
-            self.start_span = self._start_span
-            self.trace = self._trace
-
-            debtcollector.deprecate(
-                "Tracing with a tracer that has been shut down is deprecated",
-                message="A new tracer should be created for generating new traces.",
-                category=DDTraceDeprecationWarning,
-                removal_version="1.0.0",
-            )
-
-    def _shutdown_start_span(
-        self,
-        name,  # type: str
-        child_of=None,  # type: Optional[Union[Span, Context]]
-        service=None,  # type: Optional[str]
-        resource=None,  # type: Optional[str]
-        span_type=None,  # type: Optional[str]
-        activate=False,  # type: bool
-    ):
-        # type: (...) -> Span
-        self._restore_from_shutdown()
-
-        return self.start_span(name, child_of, service, resource, span_type, activate)
-
-    def _shutdown_trace(self, name, service=None, resource=None, span_type=None):
-        # type: (str, Optional[str], Optional[str], Optional[str]) -> Span
-        self._restore_from_shutdown()
-
-        return self.trace(name, service, resource, span_type)
-
     def shutdown(self, timeout=None):
         # type: (Optional[float]) -> None
-        """Shutdown the tracer.
-
-        This will stop the background writer/worker and flush any finished traces in the buffer. The tracer cannot be
-        used for tracing after this method has been called. A new tracer instance is required to continue tracing.
+        """Shutdown the tracer and flush finished traces. Avoid calling shutdown multiple times.
 
         :param timeout: How long in seconds to wait for the background worker to flush traces
             before exiting or :obj:`None` to block until flushing has successfully completed (default: :obj:`None`)
         :type timeout: :obj:`int` | :obj:`float` | :obj:`None`
         """
-        try:
-            self._writer.stop(timeout=timeout)
-        except service.ServiceStatusError:
-            # It's possible the writer never got started in the first place :(
-            pass
-
         with self._shutdown_lock:
+            # Thread safety: Ensures tracer is shutdown synchronously
+            span_processors = self._span_processors
+            self._span_processors = []
+            for processor in span_processors:
+                if hasattr(processor, "shutdown"):
+                    processor.shutdown(timeout)
+
             atexit.unregister(self._atexit)
             forksafe.unregister(self._child_after_fork)
 
-            self.start_span = self._shutdown_start_span  # type: ignore[assignment]
-            self.trace = self._shutdown_trace  # type: ignore[assignment]
+        self.start_span = self._start_span_after_shutdown  # type: ignore[assignment]
 
     @staticmethod
     def _use_log_writer():
